@@ -26,7 +26,7 @@ class ExecutionDecision:
     time_in_force: Optional[TimeInForce] = None
 
     def serialize(self) -> Dict[str, Any]:
-        data: Dict[str, Any] = self.__dict__
+        data: Dict[str, Any] = deepcopy(self.__dict__)
 
         data["execution_type"] = self.execution_type.value()
         data["time"] = str(self.time)
